@@ -33,7 +33,9 @@ class MaskedLM:
                  max_length: int = None,
                  device: str = None,
                  num_gpus: int = None,
-                 torch_dtype=None):
+                 torch_dtype=None,
+                 device_map: str = None,
+                 low_cpu_mem_usage: bool = False):
         """ Masked Language Model.
 
         @param model: Model alias or path to local model file.
@@ -49,13 +51,13 @@ class MaskedLM:
             model, local_files_only=local_files_only, use_auth_token=use_auth_token)
         self.config = transformers.AutoConfig.from_pretrained(
             model, local_files_only=local_files_only, use_auth_token=use_auth_token)
-        if torch_dtype is None:
-            self.model = transformers.AutoModelForMaskedLM.from_pretrained(
-                model, config=self.config, local_files_only=local_files_only, use_auth_token=use_auth_token)
-        else:
-            self.model = transformers.AutoModelForMaskedLM.from_pretrained(
-                model, config=self.config, local_files_only=local_files_only, use_auth_token=use_auth_token,
-                torch_dtype=torch_dtype)
+        param = {"config": self.config, "local_files_only": local_files_only, "use_auth_token": use_auth_token,
+                 "low_cpu_mem_usage": low_cpu_mem_usage}
+        if torch_dtype is not None:
+            param['torch_dtype'] = torch_dtype
+        if device_map is not None:
+            param['device_map'] = device_map
+        self.model = transformers.AutoModelForMaskedLM.from_pretrained(model, **param)
         if max_length is None:
             self.max_length = None
         else:
